@@ -44,6 +44,7 @@
 #include "kis_meta_data_store.h"
 #include "kis_selection.h"
 #include "kis_paint_layer.h"
+#include "kis_raster_keyframe_channel.h"
 
 #include "kis_clone_layer.h"
 
@@ -128,6 +129,9 @@ struct Q_DECL_HIDDEN KisLayer::Private
     KisAbstractProjectionPlaneSP layerStyleProjectionPlane;
 
     KisAbstractProjectionPlaneSP projectionPlane;
+
+    KisSelectionMaskSP selectionMask;
+    QList<KisEffectMaskSP> effectMasks;
 };
 
 
@@ -140,6 +144,7 @@ KisLayer::KisLayer(KisImageWSP image, const QString &name, quint8 opacity)
     m_d->image = image;
     m_d->metaDataStore = new KisMetaData::Store();
     m_d->projectionPlane = toQShared(new KisLayerProjectionPlane(this));
+    notifyChildMaskChanged(KisNodeSP());
 }
 
 KisLayer::KisLayer(const KisLayer& rhs)
@@ -157,6 +162,7 @@ KisLayer::KisLayer(const KisLayer& rhs)
         if (rhs.m_d->layerStyle) {
             setLayerStyle(rhs.m_d->layerStyle->clone());
         }
+        notifyChildMaskChanged(KisNodeSP());
     }
 }
 
@@ -308,7 +314,7 @@ bool KisLayer::temporary() const
 
 void KisLayer::setTemporary(bool t)
 {
-    nodeProperties().setProperty("temporary", t);
+    setNodeProperty("temporary", t);
 }
 
 KisImageWSP KisLayer::image() const
@@ -427,7 +433,18 @@ void KisLayer::updateClones(const QRect &rect)
     m_d->clonesList.setDirty(rect);
 }
 
+void KisLayer::notifyChildMaskChanged(KisNodeSP changedChildMask)
+{
+    updateSelectionMask();
+    updateEffectMasks();
+}
+
 KisSelectionMaskSP KisLayer::selectionMask() const
+{
+    return m_d->selectionMask;
+}
+
+void KisLayer::updateSelectionMask()
 {
     KoProperties properties;
     properties.setProperty("active", true);
@@ -436,10 +453,11 @@ KisSelectionMaskSP KisLayer::selectionMask() const
     // return the first visible mask
     Q_FOREACH (KisNodeSP mask, masks) {
         if (mask->visible()) {
-            return dynamic_cast<KisSelectionMask*>(mask.data());
+            m_d->selectionMask = dynamic_cast<KisSelectionMask*>(mask.data());
+            return;
         }
     }
-    return 0;
+    m_d->selectionMask = KisSelectionMaskSP();
 }
 
 KisSelectionSP KisLayer::selection() const
@@ -460,7 +478,27 @@ KisSelectionSP KisLayer::selection() const
 ///////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////
 
+const QList<KisEffectMaskSP> &KisLayer::effectMasks() const
+{
+    return m_d->effectMasks;
+}
+
 QList<KisEffectMaskSP> KisLayer::effectMasks(KisNodeSP lastNode) const
+{
+    if (lastNode.isNull()) {
+        return effectMasks();
+    } else {
+        // happens rarely.
+        return searchEffectMasks(lastNode);
+    }
+}
+
+void KisLayer::updateEffectMasks()
+{
+    m_d->effectMasks = searchEffectMasks(KisNodeSP());
+}
+
+QList<KisEffectMaskSP> KisLayer::searchEffectMasks(KisNodeSP lastNode) const
 {
     QList<KisEffectMaskSP> masks;
 
@@ -469,7 +507,7 @@ QList<KisEffectMaskSP> KisLayer::effectMasks(KisNodeSP lastNode) const
         properties.setProperty("visible", true);
         QList<KisNodeSP> nodes = childNodes(QStringList("KisEffectMask"), properties);
 
-        Q_FOREACH (const KisNodeSP& node,  nodes) {
+        Q_FOREACH (const KisNodeSP& node, nodes) {
             if (node == lastNode) break;
 
             KisEffectMaskSP mask = dynamic_cast<KisEffectMask*>(const_cast<KisNode*>(node.data()));
@@ -477,22 +515,13 @@ QList<KisEffectMaskSP> KisLayer::effectMasks(KisNodeSP lastNode) const
                 masks.append(mask);
         }
     }
+
     return masks;
 }
 
 bool KisLayer::hasEffectMasks() const
 {
-    if (childCount() == 0) return false;
-
-    KisNodeSP node = firstChild();
-    while (node) {
-        if (node->inherits("KisEffectMask") && node->visible()) {
-            return true;
-        }
-        node = node->nextSibling();
-    }
-
-    return false;
+    return  !m_d->effectMasks.empty();
 }
 
 QRect KisLayer::masksChangeRect(const QList<KisEffectMaskSP> &masks,
@@ -776,6 +805,13 @@ QRect KisLayer::changeRect(const QRect &rect, PositionToFilthy pos) const
     return changeRect;
 }
 
+void KisLayer::childNodeChanged(KisNodeSP changedChildNode)
+{
+    if (dynamic_cast<KisMask*>(changedChildNode.data())) {
+        notifyChildMaskChanged(changedChildNode);
+    }
+}
+
 QRect KisLayer::incomingChangeRect(const QRect &rect) const
 {
     return rect;
@@ -800,6 +836,29 @@ QImage KisLayer::createThumbnail(qint32 w, qint32 h)
                                            KoColorConversionTransformation::internalConversionFlags()) : QImage();
 }
 
+QImage KisLayer::createThumbnailForFrame(qint32 w, qint32 h, int time)
+{
+    if (w == 0 || h == 0) {
+        return QImage();
+    }
+
+    KisPaintDeviceSP originalDevice = original();
+    if (originalDevice) {
+        KisRasterKeyframeChannel *channel = originalDevice->keyframeChannel();
+
+        if (channel) {
+            KisPaintDeviceSP targetDevice = new KisPaintDevice(colorSpace());
+            KisKeyframeSP keyframe = channel->activeKeyframeAt(time);
+            channel->fetchFrame(keyframe, targetDevice);
+            return targetDevice->createThumbnail(w, h, 1,
+                                                 KoColorConversionTransformation::internalRenderingIntent(),
+                                                 KoColorConversionTransformation::internalConversionFlags());
+        }
+    }
+
+    return createThumbnail(w, h);
+}
+
 qint32 KisLayer::x() const
 {
     KisPaintDeviceSP originalDevice = original();
