@@ -66,6 +66,7 @@ struct Q_DECL_HIDDEN KisMask::Private {
     QScopedPointer<QPoint> deferredSelectionOffset;
 
     KisAbstractProjectionPlaneSP projectionPlane;
+    KisCachedSelection cachedSelection;
 
     void initSelectionImpl(KisSelectionSP copyFrom, KisLayerSP parentLayer, KisPaintDeviceSP copyFromDevice);
 };
@@ -245,17 +246,47 @@ void KisMask::apply(KisPaintDeviceSP projection, const QRect &applyRect, const Q
 
         m_d->selection->updateProjection(applyRect);
 
-        if(!extent().intersects(applyRect))
-            return;
+        KisSelectionSP effectiveSelection = m_d->selection;
+        QRect effectiveExtent = effectiveSelection->selectedRect();
+
+        {
+            // Access temporary target under the lock held
+            KisIndirectPaintingSupport::ReadLocker l(this);
+
+            if (hasTemporaryTarget()) {
+                effectiveExtent |= temporaryTarget()->extent();
+            }
+
+            if(!effectiveExtent.intersects(applyRect)) {
+                return;
+            }
+
+            if (hasTemporaryTarget()) {
+                effectiveSelection = m_d->cachedSelection.getSelection();
+                effectiveSelection->setDefaultBounds(m_d->selection->pixelSelection()->defaultBounds());
+
+                KisPainter::copyAreaOptimized(applyRect.topLeft(),
+                                              m_d->selection->pixelSelection(),
+                                              effectiveSelection->pixelSelection(), applyRect);
+
+                KisPainter gc(effectiveSelection->pixelSelection());
+                setupTemporaryPainter(&gc);
+                gc.bitBlt(applyRect.topLeft(), temporaryTarget(), applyRect);
+            }
+        }
 
         KisPaintDeviceSP cacheDevice = m_d->paintDeviceCache.getDevice(projection);
 
         QRect updatedRect = decorateRect(projection, cacheDevice, applyRect, maskPos);
 
         // masks don't have any compositioning
-        KisPainter::copyAreaOptimized(updatedRect.topLeft(), cacheDevice, projection, updatedRect, m_d->selection);
+        KisPainter::copyAreaOptimized(updatedRect.topLeft(), cacheDevice, projection, updatedRect, effectiveSelection);
         m_d->paintDeviceCache.putDevice(cacheDevice);
 
+        if (effectiveSelection != m_d->selection) {
+            m_d->cachedSelection.putSelection(effectiveSelection);
+        }
+
     } else {
         KisPaintDeviceSP cacheDevice = m_d->paintDeviceCache.getDevice(projection);
 
@@ -379,3 +410,12 @@ KisKeyframeChannel *KisMask::requestKeyframeChannel(const QString &id)
     return KisNode::requestKeyframeChannel(id);
 }
 
+void KisMask::baseNodeChangedCallback()
+{
+    KisNodeSP up = parent();
+    KisLayer *layer = dynamic_cast<KisLayer*>(up.data());
+    if (layer) {
+        layer->notifyChildMaskChanged(this);
+    }
+    KisNode::baseNodeChangedCallback();
+}
