@@ -72,7 +72,7 @@ public:
     /**
      *  Destructor.
      */
-    virtual ~KisMainWindow();
+    ~KisMainWindow() override;
 
     /**
      * Update caption from document info - call when document info
@@ -123,7 +123,7 @@ public:
 
     QDockWidget* dockWidget(const QString &id);
 
-    QList<KoCanvasObserverBase*> canvasObservers() const;
+    QList<KoCanvasObserverBase*> canvasObservers() const override;
 
     KoCanvasResourceManager *resourceManager() const;
 
@@ -216,6 +216,7 @@ public Q_SLOTS:
      */
     void slotFileSave();
 
+    // XXX: disabled
     KisPrintJob* exportToPdf(const QString &pdfFileName = QString());
 
     void slotProgress(int value);
@@ -241,6 +242,8 @@ public Q_SLOTS:
     void newOptionWidgets(KoCanvasController *controller, const QList<QPointer<QWidget> > & optionWidgetList);
 
 
+    void notifyChildViewDestroyed(KisView *view);
+
 private Q_SLOTS:
     /**
      * Save the list of recent files.
@@ -368,19 +371,18 @@ private Q_SLOTS:
 
 protected:
 
-    void closeEvent(QCloseEvent * e);
-    void resizeEvent(QResizeEvent * e);
+    void closeEvent(QCloseEvent * e) override;
+    void resizeEvent(QResizeEvent * e) override;
 
     /// Set the active view, this will update the undo/redo actions
     virtual void setActiveView(KisView *view);
 
     // QWidget overrides
-    virtual void dragEnterEvent(QDragEnterEvent * event);
-    virtual void dropEvent(QDropEvent * event);
-    virtual void dragMoveEvent(QDragMoveEvent * event);
-    virtual void dragLeaveEvent(QDragLeaveEvent * event);
+    void dragEnterEvent(QDragEnterEvent * event) override;
+    void dropEvent(QDropEvent * event) override;
+    void dragMoveEvent(QDragMoveEvent * event) override;
+    void dragLeaveEvent(QDragLeaveEvent * event) override;
 
-    void setToolbarList(QList<QAction*> toolbarList);
 
 private:
     /**
@@ -449,7 +451,7 @@ private:
 
 protected:
 
-    void moveEvent(QMoveEvent *e);
+    void moveEvent(QMoveEvent *e) override;
 
 private Q_SLOTS:
     void initializeGeometry();
