@@ -319,7 +319,9 @@ KActionCollection *KisViewManager::actionCollection() const
 
 void KisViewManager::slotViewAdded(KisView *view)
 {
-    d->inputManager.addTrackedCanvas(view->canvasBase());
+    // WARNING: this slot is called even when a view from another main windows is added!
+    //          Don't expect \p view be a child of this view manager!
+    Q_UNUSED(view);
 
     if (viewCount() == 0) {
         d->statusBar.showAllStatusBarItems();
@@ -328,7 +330,9 @@ void KisViewManager::slotViewAdded(KisView *view)
 
 void KisViewManager::slotViewRemoved(KisView *view)
 {
-    d->inputManager.removeTrackedCanvas(view->canvasBase());
+    // WARNING: this slot is called even when a view from another main windows is removed!
+    //          Don't expect \p view be a child of this view manager!
+    Q_UNUSED(view);
 
     if (viewCount() == 0) {
         d->statusBar.hideAllStatusBarItems();
@@ -352,17 +356,17 @@ void KisViewManager::setCurrentView(KisView *view)
     }
 
 
-    d->softProof->setChecked(view->softProofing());
-    d->gamutCheck->setChecked(view->gamutCheck());
-
-    QPointer<KisView>imageView = qobject_cast<KisView*>(view);
+    QPointer<KisView> imageView = qobject_cast<KisView*>(view);
+    d->currentImageView = imageView;
 
     if (imageView) {
+        d->softProof->setChecked(imageView->softProofing());
+        d->gamutCheck->setChecked(imageView->gamutCheck());
+
         // Wait for the async image to have loaded
         KisDocument* doc = view->document();
         //        connect(canvasController()->proxyObject, SIGNAL(documentMousePositionChanged(QPointF)), d->statusBar, SLOT(documentMousePositionChanged(QPointF)));
 
-        d->currentImageView = imageView;
         // Restore the last used brush preset, color and background color.
         if (first) {
             KisConfig cfg;
@@ -433,31 +437,31 @@ void KisViewManager::setCurrentView(KisView *view)
         d->currentImageView->notifyCurrentStateChanged(true);
         d->currentImageView->canvasController()->activate();
         d->currentImageView->canvasController()->setFocus();
+
+        d->viewConnections.addUniqueConnection(
+            image(), SIGNAL(sigSizeChanged(const QPointF&, const QPointF&)),
+            resourceProvider(), SLOT(slotImageSizeChanged()));
+
+        d->viewConnections.addUniqueConnection(
+            image(), SIGNAL(sigResolutionChanged(double,double)),
+            resourceProvider(), SLOT(slotOnScreenResolutionChanged()));
+
+        d->viewConnections.addUniqueConnection(
+            image(), SIGNAL(sigNodeChanged(KisNodeSP)),
+            this, SLOT(updateGUI()));
+
+        d->viewConnections.addUniqueConnection(
+            d->currentImageView->zoomManager()->zoomController(),
+            SIGNAL(zoomChanged(KoZoomMode::Mode,qreal)),
+            resourceProvider(), SLOT(slotOnScreenResolutionChanged()));
+
     }
 
     d->actionManager.updateGUI();
 
-    d->viewConnections.addUniqueConnection(
-        image(), SIGNAL(sigSizeChanged(const QPointF&, const QPointF&)),
-        resourceProvider(), SLOT(slotImageSizeChanged()));
-
-    d->viewConnections.addUniqueConnection(
-        image(), SIGNAL(sigResolutionChanged(double,double)),
-        resourceProvider(), SLOT(slotOnScreenResolutionChanged()));
-
-    d->viewConnections.addUniqueConnection(
-        image(), SIGNAL(sigNodeChanged(KisNodeSP)),
-        this, SLOT(updateGUI()));
-
-    d->viewConnections.addUniqueConnection(
-        view->zoomManager()->zoomController(),
-        SIGNAL(zoomChanged(KoZoomMode::Mode,qreal)),
-        resourceProvider(), SLOT(slotOnScreenResolutionChanged()));
-
     resourceProvider()->slotImageSizeChanged();
     resourceProvider()->slotOnScreenResolutionChanged();
 
-
     Q_EMIT viewChanged();
 }
 
@@ -652,6 +656,7 @@ void KisViewManager::createActions()
     a = actionManager()->createAction("edit_blacklist_cleanup");
     connect(a, SIGNAL(triggered()), this, SLOT(slotBlacklistCleanup()));
 
+    actionManager()->createAction("ruler_pixel_multiple2");
     d->showRulersAction = actionManager()->createAction("view_ruler");
     d->showRulersAction->setChecked(cfg.showRulers());
     connect(d->showRulersAction, SIGNAL(toggled(bool)), SLOT(slotSaveShowRulersState(bool)));
