@@ -22,6 +22,7 @@
 #include <QScopedPointer>
 #include <QObject>
 #include "kritaui_export.h"
+#include <KoUnit.h>
 
 class KisView;
 class KisActionManager;
@@ -34,7 +35,7 @@ class KRITAUI_EXPORT KisGuidesManager : public QObject
     Q_OBJECT
 public:
     KisGuidesManager(QObject *parent = 0);
-    ~KisGuidesManager();
+    ~KisGuidesManager() override;
 
     void setup(KisActionManager *actionManager);
     void setView(QPointer<KisView> view);
@@ -42,8 +43,11 @@ public:
     bool showGuides() const;
     bool lockGuides() const;
     bool snapToGuides() const;
+    bool rulersMultiple2() const;
 
-    bool eventFilter(QObject *obj, QEvent *event);
+    KoUnit::Type unitType() const;
+
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
 Q_SIGNALS:
     void sigRequestUpdateGuidesConfig(const KisGuidesConfig &config);
@@ -55,6 +59,8 @@ public Q_SLOTS:
     void setShowGuides(bool value);
     void setLockGuides(bool value);
     void setSnapToGuides(bool value);
+    void setRulersMultiple2(bool value);
+    void setUnitType(KoUnit::Type type);
 
     void slotGuideCreationInProgress(Qt::Orientation orientation, const QPoint &globalPos);
     void slotGuideCreationFinished(Qt::Orientation orientation, const QPoint &globalPos);
