@@ -583,7 +583,10 @@ void KisPaintopBox::setCurrentPaintop(KisPaintOpPresetSP preset)
     //qDebug() << "setCurrentPaintop(); " << preset->name();
 
     if (preset == m_resourceProvider->currentPreset()) {
-        return;
+
+        if (preset == m_tabletToolMap[m_currTabletToolID].preset) {
+            return;
+        }
     }
     Q_ASSERT(preset);
     const KoID& paintop = preset->paintOp();
@@ -698,7 +701,7 @@ void KisPaintopBox::updateCompositeOp(QString compositeOpID)
         if (compositeOpID != m_currCompositeOpID) {
             m_currCompositeOpID = compositeOpID;
         }
-        if (compositeOpID == COMPOSITE_ERASE) {
+        if (compositeOpID == COMPOSITE_ERASE || m_resourceProvider->eraserMode()) {
             m_eraseModeButton->setChecked(true);
         }
         else {
@@ -755,6 +758,8 @@ void KisPaintopBox::slotInputDeviceChanged(const KoInputDevice& inputDevice)
 
     //qDebug() << "slotInputDeviceChanged()" << inputDevice.device() << inputDevice.uniqueTabletId();
 
+    m_currTabletToolID = TabletToolID(inputDevice);
+
     if (toolData == m_tabletToolMap.end()) {
         KisConfig cfg;
         KisPaintOpPresetResourceServer *rserver = KisResourceServerProvider::instance()->paintOpPresetServer(false);
@@ -787,8 +792,6 @@ void KisPaintopBox::slotInputDeviceChanged(const KoInputDevice& inputDevice)
             setCurrentPaintop(toolData->paintOpID);
         }
     }
-
-    m_currTabletToolID = TabletToolID(inputDevice);
 }
 
 void KisPaintopBox::slotCanvasResourceChanged(int key, const QVariant &value)
@@ -1081,13 +1084,20 @@ void KisPaintopBox::slotToolChanged(KoCanvasController* canvas, int toolId)
         }
 
         if (flags & KisTool::FLAG_USES_CUSTOM_PRESET) {
-            setWidgetState(ENABLE_PRESETS | ENABLE_SIZE | ENABLE_FLOW);
+            setWidgetState(ENABLE_PRESETS);
             slotUpdatePreset();
             m_presetsEnabled = true;
         } else {
-            setWidgetState(DISABLE_PRESETS | DISABLE_SIZE | DISABLE_FLOW);
+            setWidgetState(DISABLE_PRESETS);
             m_presetsEnabled = false;
         }
+
+        if (flags & KisTool::FLAG_USES_CUSTOM_SIZE) {
+            setWidgetState(ENABLE_SIZE | ENABLE_FLOW);
+        } else {
+            setWidgetState(DISABLE_SIZE | DISABLE_FLOW);
+        }
+
     } else setWidgetState(DISABLE_ALL);
 }
 
