@@ -381,14 +381,15 @@ void KisKraLoader::loadBinaryData(KoStore * store, KisImageSP image, const QStri
             proofingData.resize(store->size());
             bool proofingProfileRes = (store->read(proofingData.data(), store->size())>-1);
             store->close();
-            if (proofingProfileRes)
-            {
-                const KoColorProfile *proofingProfile = KoColorSpaceRegistry::instance()->createColorProfile(image->proofingConfiguration()->proofingModel, image->proofingConfiguration()->proofingDepth, proofingData);
-                if (proofingProfile->valid()){
 
-                    //if (KoColorSpaceEngineRegistry::instance()->get("icc")) {
-                    //    KoColorSpaceEngineRegistry::instance()->get("icc")->addProfile(proofingProfile->fileName());
-                    //}
+            KisProofingConfigurationSP proofingConfig = image->proofingConfiguration();
+            if (!proofingConfig) {
+                proofingConfig = KisImageConfig().defaultProofingconfiguration();
+            }
+
+            if (proofingProfileRes) {
+                const KoColorProfile *proofingProfile = KoColorSpaceRegistry::instance()->createColorProfile(proofingConfig->proofingModel, proofingConfig->proofingDepth, proofingData);
+                if (proofingProfile->valid()){
                     KoColorSpaceRegistry::instance()->addProfile(proofingProfile);
                 }
             }
@@ -788,7 +789,7 @@ KisNodeSP KisKraLoader::loadFileLayer(const KoXmlElement& element, KisImageSP im
     QFileInfo info(documentPath);
     QString basePath = info.absolutePath();
 
-    QString fullPath = basePath + QDir::separator() + filename;
+    QString fullPath = QDir(basePath).filePath(QDir::cleanPath(filename));
     // Entering the event loop to show the messagebox will delete the image, so up the ref by one
     image->ref();
     if (!QFileInfo(fullPath).exists()) {
