@@ -20,13 +20,14 @@
 
 /** @file */
 
-#include <KoConfig.h>
-
 #include <QtGlobal>
-class QOpenGLContext;
+#include <QFlags>
 
 #include "kritaui_export.h"
 
+class QOpenGLContext;
+class QString;
+class QStringList;
 
 /**
  * This class manages a shared OpenGL context and provides utility
@@ -43,14 +44,41 @@ public:
     };
 public:
 
+#ifdef Q_OS_WIN
+    enum OpenGLRenderer {
+        RendererNone = 0x00,
+        RendererAuto = 0x01,
+        RendererDesktopGL = 0x02,
+        RendererAngle = 0x04,
+    };
+    Q_DECLARE_FLAGS(OpenGLRenderers, OpenGLRenderer);
+
+    // Probe the Windows platform abstraction layer for OpenGL detection
+    static void probeWindowsQpaOpenGL(int argc, char **argv, QString userRendererConfigString);
+
+    static OpenGLRenderer getCurrentOpenGLRenderer();
+    static OpenGLRenderer getQtPreferredOpenGLRenderer();
+    static OpenGLRenderers getSupportedOpenGLRenderers();
+    static OpenGLRenderer getUserOpenGLRendererConfig();
+    static OpenGLRenderer getNextUserOpenGLRendererConfig();
+    static void setNextUserOpenGLRendererConfig(OpenGLRenderer renderer);
+    static QString convertOpenGLRendererToConfig(OpenGLRenderer renderer);
+    static OpenGLRenderer convertConfigToOpenGLRenderer(QString renderer);
+#endif
+
     /// Request OpenGL version 3.2
     static void initialize();
 
     /// Initialize shared OpenGL context
     static void initializeContext(QOpenGLContext *ctx);
 
+    static const QString &getDebugText();
+
+    static QStringList getOpenGLWarnings();
+
     static bool supportsLoD();
     static bool hasOpenGL3();
+    static bool hasOpenGLES();
 
     /// Check for OpenGL
     static bool hasOpenGL();
@@ -72,7 +100,7 @@ public:
      */
     static bool needsPixmapCacheWorkaround();
 
-    static void setDefaultFormat();
+    static void setDefaultFormat(bool enableDebug = false, bool debugSynchronous = false);
 
 private:
 
@@ -82,4 +110,8 @@ private:
 
 };
 
+#ifdef Q_OS_WIN
+Q_DECLARE_OPERATORS_FOR_FLAGS(KisOpenGL::OpenGLRenderers);
+#endif
+
 #endif // KIS_OPENGL_H_
