@@ -27,9 +27,9 @@ class OraExport : public KisImportExportFilter
     Q_OBJECT
 public:
     OraExport(QObject *parent, const QVariantList &);
-    virtual ~OraExport();
+    ~OraExport() override;
 public:
-    virtual KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0);
+    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
 };
 
 #endif
